summaryrefslogtreecommitdiff
path: root/includes/revisiondelete/RevisionDeleteUser.php
diff options
context:
space:
mode:
Diffstat (limited to 'includes/revisiondelete/RevisionDeleteUser.php')
-rw-r--r--includes/revisiondelete/RevisionDeleteUser.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/includes/revisiondelete/RevisionDeleteUser.php b/includes/revisiondelete/RevisionDeleteUser.php
index 55c46c5e..79802d66 100644
--- a/includes/revisiondelete/RevisionDeleteUser.php
+++ b/includes/revisiondelete/RevisionDeleteUser.php
@@ -36,14 +36,14 @@ class RevisionDeleteUser {
* @param string $name Username
* @param int $userId User id
* @param string $op Operator '|' or '&'
* @param null|DatabaseBase $dbw If you happen to have one lying around
* @return bool
*/
private static function setUsernameBitfields( $name, $userId, $op, $dbw ) {
if ( !$userId || ( $op !== '|' && $op !== '&' ) ) {
return false; // sanity check
}
- if ( !$dbw instanceof DatabaseBase ) {
+ if ( !$dbw instanceof IDatabase ) {
$dbw = wfGetDB( DB_MASTER );
}
@@ -36,14 +36,14 @@ class RevisionDeleteUser {
* @param int $userId User id
* @param string $op Operator '|' or '&'
- * @param null|DatabaseBase $dbw If you happen to have one lying around
+ * @param null|IDatabase $dbw If you happen to have one lying around
* @return bool
*/